@@ -26,11 +26,10 @@ GObject.threads_init()
 
 import gi
 gi.require_version('Gtk', '3.0')
-gi.require_version('GConf', '2.0')
+gi.require_version('TelepathyGLib', '0.12')
+
 from gi.repository import Gtk
-from gi.repository import GConf
-import telepathy
-import telepathy.client
+from gi.repository import TelepathyGLib
 
 from sugar3.activity import activity
 from sugar3.activity.widgets import StopButton
@@ -42,6 +41,8 @@ from sugar3.graphics.toolbarbox import ToolbarButton, ToolbarBox
 from sugar3.graphics import style
 from sugar3.graphics.icon import Icon
 from sugar3.graphics.xocolor import XoColor
+from sugar3.graphics.palettemenu import PaletteMenuBox
+from sugar3.graphics.palettemenu import PaletteMenuItem
 
 from toolbar import EditToolbar
 from toolbar import ViewToolbar
@@ -137,18 +138,17 @@ class AbiWordActivity(activity.Activity):
 
         image = ToolButton('insert-picture')
         image.set_tooltip(_('Insert Image'))
-        self._image_id = image.connect('clicked', self._image_cb)
+        self._image_id = image.connect('clicked', self.__image_cb)
         toolbar_box.toolbar.insert(image, -1)
 
         palette = image.get_palette()
-        content_box = Gtk.VBox()
-        palette.set_content(content_box)
-        image_floating_checkbutton = Gtk.CheckButton(_('Floating'))
-        image_floating_checkbutton.connect(
-            'toggled', self._image_floating_checkbutton_toggled_cb)
-        content_box.pack_start(image_floating_checkbutton, True, True, 0)
-        content_box.show_all()
-        self.floating_image = False
+        box = PaletteMenuBox()
+        palette.set_content(box)
+        box.show()
+        menu_item = PaletteMenuItem(_('Floating'))
+        menu_item.connect('activate', self.__image_cb, True)
+        box.append_item(menu_item)
+        menu_item.show()
 
         separator = Gtk.SeparatorToolItem()
         separator.props.draw = False
@@ -176,16 +176,9 @@ class AbiWordActivity(activity.Activity):
         # we want a nice border so we can select paragraphs easily
         self.abiword_canvas.set_show_margin(True)
 
-        # Read default font face and size
-        client = GConf.Client.get_default()
-        self._default_font_face = client.get_string(
-            '/desktop/sugar/activities/write/font_face')
-        if not self._default_font_face:
-            self._default_font_face = 'Sans'
-        self._default_font_size = client.get_int(
-            '/desktop/sugar/activities/write/font_size')
-        if self._default_font_size == 0:
-            self._default_font_size = 12
+        # Set default font face and size
+        self._default_font_face = 'Sans'
+        self._default_font_size = 12
 
         # activity sharing
         self.participants = {}
@@ -195,7 +188,7 @@ class AbiWordActivity(activity.Activity):
 
         if self.shared_activity:
             # we are joining the activity
-            logger.error('We are joining an activity')
+            logger.debug('We are joining an activity')
             # display a icon while joining
             self._connecting_box.show()
             # disable the abi widget
@@ -209,7 +202,7 @@ class AbiWordActivity(activity.Activity):
                 self._joined_cb(self)
         else:
             # we are creating the activity
-            logger.error("We are creating an activity")
+            logger.debug("We are creating an activity")
 
         self.abiword_canvas.zoom_width()
         self.abiword_canvas.show()
@@ -231,7 +224,7 @@ class AbiWordActivity(activity.Activity):
     def __map_activity_event_cb(self, event, activity):
         # set custom keybindings for Write
         # we do it later because have problems if done before - OLPC #11049
-        logger.error('Loading keybindings')
+        logger.debug('Loading keybindings')
         keybindings_file = os.path.join(get_bundle_path(), 'keybindings.xml')
         self.abiword_canvas.invoke_ex(
             'com.abisource.abiword.loadbindings.fromURI',
@@ -239,7 +232,7 @@ class AbiWordActivity(activity.Activity):
         # set default font
         if self._new_instance:
             self.abiword_canvas.select_all()
-            logging.error('Setting default font to %s %d in new documents',
+            logging.debug('Setting default font to %s %d in new documents',
                           self._default_font_face, self._default_font_size)
             self.abiword_canvas.set_font_name(self._default_font_face)
             self.abiword_canvas.set_font_size(str(self._default_font_size))
@@ -274,16 +267,16 @@ class AbiWordActivity(activity.Activity):
         return preview_data
 
     def _shared_cb(self, activity):
-        logger.error('My Write activity was shared')
+        logger.debug('My Write activity was shared')
         self._sharing_setup()
 
         self.shared_activity.connect('buddy-joined', self._buddy_joined_cb)
         self.shared_activity.connect('buddy-left', self._buddy_left_cb)
 
-        channel = self.tubes_chan[telepathy.CHANNEL_TYPE_TUBES]
-        logger.error('This is my activity: offering a tube...')
+        channel = self.tubes_chan[TelepathyGLib.IFACE_CHANNEL_TYPE_TUBES]
+        logger.debug('This is my activity: offering a tube...')
         id = channel.OfferDBusTube('com.abisource.abiword.abicollab', {})
-        logger.error('Tube address: %s', channel.GetDBusTubeAddress(id))
+        logger.debug('Tube address: %s', channel.GetDBusTubeAddress(id))
 
     def _sharing_setup(self):
         logger.debug("_sharing_setup()")
@@ -296,7 +289,7 @@ class AbiWordActivity(activity.Activity):
         self.tubes_chan = self.shared_activity.telepathy_tubes_chan
         self.text_chan = self.shared_activity.telepathy_text_chan
         self.tube_id = None
-        self.tubes_chan[telepathy.CHANNEL_TYPE_TUBES].connect_to_signal(
+        self.tubes_chan[TelepathyGLib.IFACE_CHANNEL_TYPE_TUBES].connect_to_signal(
             'NewTube', self._new_tube_cb)
 
     def _list_tubes_reply_cb(self, tubes):
@@ -307,17 +300,17 @@ class AbiWordActivity(activity.Activity):
         logger.error('ListTubes() failed: %s', e)
 
     def _joined_cb(self, activity):
-        logger.error("_joined_cb()")
+        logger.debug("_joined_cb()")
         if not self.shared_activity:
             self._enable_collaboration()
             return
 
         self.joined = True
-        logger.error('Joined an existing Write session')
+        logger.debug('Joined an existing Write session')
         self._sharing_setup()
 
-        logger.error('This is not my activity: waiting for a tube...')
-        self.tubes_chan[telepathy.CHANNEL_TYPE_TUBES].ListTubes(
+        logger.debug('This is not my activity: waiting for a tube...')
+        self.tubes_chan[TelepathyGLib.IFACE_CHANNEL_TYPE_TUBES].ListTubes(
             reply_handler=self._list_tubes_reply_cb,
             error_handler=self._list_tubes_error_cb)
         self._enable_collaboration()
@@ -332,7 +325,7 @@ class AbiWordActivity(activity.Activity):
         self._connecting_box.hide()
 
     def _new_tube_cb(self, id, initiator, type, service, params, state):
-        logger.error('New tube: ID=%d initiator=%d type=%d service=%s '
+        logger.debug('New tube: ID=%d initiator=%d type=%d service=%s '
                      'params=%r state=%d', id, initiator, type, service,
                      params, state)
 
@@ -340,13 +333,13 @@ class AbiWordActivity(activity.Activity):
             # We are already using a tube
             return
 
-        if type != telepathy.TUBE_TYPE_DBUS or \
+        if type != TelepathyGLib.TubeType.DBUS or \
                 service != "com.abisource.abiword.abicollab":
             return
 
-        channel = self.tubes_chan[telepathy.CHANNEL_TYPE_TUBES]
+        channel = self.tubes_chan[TelepathyGLib.IFACE_CHANNEL_TYPE_TUBES]
 
-        if state == telepathy.TUBE_STATE_LOCAL_PENDING:
+        if state == TelepathyGLib.TubeState.LOCAL_PENDING:
             channel.AcceptDBusTube(id)
 
         # look for the initiator's D-Bus unique name
@@ -354,7 +347,7 @@ class AbiWordActivity(activity.Activity):
         dbus_names = channel.GetDBusNames(id)
         for handle, name in dbus_names:
             if handle == initiator:
-                logger.error('found initiator D-Bus name: %s', name)
+                logger.debug('found initiator D-Bus name: %s', name)
                 initiator_dbus_name = name
                 break
 
@@ -366,18 +359,18 @@ class AbiWordActivity(activity.Activity):
         # pass this tube to abicollab
         address = channel.GetDBusTubeAddress(id)
         if self.joined:
-            logger.error('Passing tube address to abicollab (join): %s',
+            logger.debug('Passing tube address to abicollab (join): %s',
                          address)
             self.abiword_canvas.invoke_ex(cmd_prefix + 'joinTube',
                                           address, 0, 0)
             # The intiator of the session has to be the first passed
             # to the Abicollab backend.
-            logger.error('Adding the initiator to the session: %s',
+            logger.debug('Adding the initiator to the session: %s',
                          initiator_dbus_name)
             self.abiword_canvas.invoke_ex(cmd_prefix + 'buddyJoined',
                                           initiator_dbus_name, 0, 0)
         else:
-            logger.error('Passing tube address to abicollab (offer): %s',
+            logger.debug('Passing tube address to abicollab (offer): %s',
                          address)
             self.abiword_canvas.invoke_ex(cmd_prefix + 'offerTube', address,
                                           0, 0)
@@ -394,11 +387,11 @@ class AbiWordActivity(activity.Activity):
         according members of the D-Bus tube. That's why we don't add/remove
         buddies in _buddy_{joined,left}_cb.
         """
-        logger.error('_on_dbus_names_changed')
+        logger.debug('_on_dbus_names_changed')
 #        if tube_id == self.tube_id:
         cmd_prefix = 'com.abisource.abiword.abicollab.olpc'
         for handle, bus_name in added:
-            logger.error('added handle: %s, with dbus_name: %s',
+            logger.debug('added handle: %s, with dbus_name: %s',
                          handle, bus_name)
             self.abiword_canvas.invoke_ex(cmd_prefix + '.buddyJoined',
                                           bus_name, 0, 0)
@@ -406,7 +399,7 @@ class AbiWordActivity(activity.Activity):
 
     def _on_members_changed(self, message, added, removed, local_pending,
                             remote_pending, actor, reason):
-        logger.error("_on_members_changed")
+        logger.debug("_on_members_changed")
         for handle in removed:
             bus_name = self.participants.pop(handle, None)
             if bus_name is None:
@@ -415,16 +408,16 @@ class AbiWordActivity(activity.Activity):
                 continue
 
             cmd_prefix = 'com.abisource.abiword.abicollab.olpc'
-            logger.error('removed handle: %d, with dbus name: %s', handle,
+            logger.debug('removed handle: %d, with dbus name: %s', handle,
                          bus_name)
             self.abiword_canvas.invoke_ex(cmd_prefix + '.buddyLeft',
                                           bus_name, 0, 0)
 
     def _buddy_joined_cb(self, activity, buddy):
-        logger.error('buddy joined with object path: %s', buddy.object_path())
+        logger.debug('buddy joined with object path: %s', buddy.object_path())
 
     def _buddy_left_cb(self, activity, buddy):
-        logger.error('buddy left with object path: %s', buddy.object_path())
+        logger.debug('buddy left with object path: %s', buddy.object_path())
 
     def read_file(self, file_path):
         logging.debug('AbiWordActivity.read_file: %s, mimetype: %s',
@@ -474,10 +467,7 @@ class AbiWordActivity(activity.Activity):
         return self.metadata['mime_type'] in ['text/plain', 'text/csv'] or \
             'text/plain' in mime_parents
 
-    def _image_floating_checkbutton_toggled_cb(self, checkbutton):
-        self.floating_image = checkbutton.get_active()
-
-    def _image_cb(self, button):
+    def __image_cb(self, button, floating=False):
         try:
             chooser = ObjectChooser(self, what_filter='Image',
                                     filter_type=FILTER_TYPE_GENERIC_MIME,
@@ -494,7 +484,7 @@ class AbiWordActivity(activity.Activity):
                 jobject = chooser.get_selected_object()
                 if jobject and jobject.file_path:
                     self.abiword_canvas.insert_image(jobject.file_path,
-                                                     self.floating_image)
+                                                     floating)
         finally:
             chooser.destroy()
             del chooser
